@@ -1,10 +1,10 @@
 /*
  * Copyright 2001-2010 Anne-Marie Mahfouf <annma@kde.org>
 
-     This program is free software; you can redistribute it and/or modify  
-     it under the terms of the GNU General Public License as published by  
-     the Free Software Foundation; either version 2 of the License, or     
-     (at your option) any later version.                                   
+     This program is free software; you can redistribute it and/or modify
+     it under the terms of the GNU General Public License as published by
+     the Free Software Foundation; either version 2 of the License, or
+     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,9 @@
 
 #include <KMessageBox>
 #include <KPassivePopup>
-#include <KPushButton>
+#include <QPushButton>
 #include <KToggleAction>
-#include <KVBox>
+#include <KLocalizedString>
 
 #include <Phonon/MediaObject>
 
@@ -38,6 +38,7 @@
 #include <QMouseEvent>
 #include <QSvgRenderer>
 #include <QRegExpValidator>
+#include <QStandardPaths>
 //project headers
 #include "prefs.h"
 #include "khangman.h"
@@ -45,10 +46,23 @@
 #include "langutils.h"
 
 
-KHangManView::KHangManView(KHangMan*parent) 
-        : QWidget(parent), khangman(parent), winCount(0), lossCount(0), m_winner(false), 
-	  m_loser(false), m_bgfill(0), m_numMissedLetters(0), m_posFirstSpace(-1), m_posSecondSpace(-1), 
-          m_randomInt(-1), m_hintExists(true), m_accentedLetters(true), m_doc(0), m_theme(0), m_player(0)
+KHangManView::KHangManView(KHangMan*parent)
+        : QWidget(parent),
+          khangman(parent),
+          m_winner(false),
+          m_loser(false),
+          m_bgfill(0),
+          m_winCount(0),
+          m_lossCount(0),
+          m_numMissedLetters(0),
+          m_posFirstSpace(-1),
+          m_posSecondSpace(-1),
+          m_randomInt(-1),
+          m_hintExists(true),
+          m_accentedLetters(true),
+          m_doc(0),
+          m_theme(0),
+          m_player(0)
 {
     setAttribute(Qt::WA_StaticContents);
 
@@ -66,16 +80,16 @@ KHangManView::KHangManView(KHangMan*parent)
     m_letterInput->setAlignment( Qt::AlignHCenter  );
 
     // Press this button to enter a letter (or press enter)
-    m_guessButton = new KPushButton( this);
+    m_guessButton = new QPushButton( this);
     m_guessButton->setObjectName( "guessButton" );
     m_guessButton->setSizePolicy( policy );
     m_guessButton->setCursor(Qt::PointingHandCursor);
     m_guessButton->setText( i18n( "G&uess" ) );
 
-    m_playAgainButton = new KPushButton(this);
+    m_playAgainButton = new QPushButton(this);
     m_playAgainButton->setCursor(Qt::PointingHandCursor);
     m_playAgainButton->setText( i18n( "&Play again" ) );
-    
+
     m_playAgainButton->setStyleSheet( QString("QPushButton { border: 2px solid black; border-radius: 15px; background-color: #969696; padding: 6px; }  QPushButton:hover { background-color: #787878 } "));
 
     setMinimumSize( QSize( 660, 370 ) );
@@ -83,7 +97,8 @@ KHangManView::KHangManView(KHangMan*parent)
     connect( m_letterInput, SIGNAL(returnPressed()), this, SLOT(slotTry()) );
     connect( m_guessButton, SIGNAL(clicked()), this, SLOT(slotTry()));
     connect( m_playAgainButton, SIGNAL(clicked()), this, SLOT(newGame()));
-    connect( this, SIGNAL(signalChangeStatusbar(QString,int)), khangman, SLOT(changeStatusbar(QString,int)));
+    connect( this, SIGNAL(signalSetWins(int)), khangman, SLOT(slotSetWins(int)));
+    connect( this, SIGNAL(signalSetLosses(int)), khangman, SLOT(slotSetLosses(int)));
     m_renderer = new QSvgRenderer();
 
     // not the best thing to do, but at least avoid no theme set
@@ -110,8 +125,8 @@ void KHangManView::replaceLetters(const QString& sChar)
     // We just replace the next instance.
         for (int count=0; count < m_word.count(sChar); ++count) {
             index = m_word.indexOf(sChar, index);
-            if (goodWord.at(2*index)=='_') {
-                goodWord.replace((2*index), 1, sChar);
+            if (m_goodWord.at(2*index)=='_') {
+                m_goodWord.replace((2*index), 1, sChar);
 
                 if (count == m_word.count(sChar)-1)
                 b_end = true;
@@ -132,7 +147,7 @@ void KHangManView::replaceLetters(const QString& sChar)
             index = m_word.indexOf(sChar, index);
 
             //we replace it...
-            goodWord.replace((2*index), 1,sChar);
+            m_goodWord.replace((2*index), 1,sChar);
             ++index;
         }
     }
@@ -176,7 +191,7 @@ void KHangManView::play(const QString& soundFile)
         m_player->stop();
     }
 
-    m_player->setCurrentSource(soundFile);
+    m_player->setCurrentSource(QUrl::fromLocalFile(soundFile));
     m_player->play();
 }
 
@@ -199,8 +214,6 @@ bool KHangManView::containsChar(const QString &sChar)
 
 // ----------------------------------------------------------------
 
-// FIXME: Move this function somewhere logical
-
 
 void KHangManView::setTheme(KHMTheme *theme)
 {
@@ -209,11 +222,11 @@ void KHangManView::setTheme(KHMTheme *theme)
         return;
     }
 
-    QString svgpath = KStandardDirs::locate("data", QString("khangman/pics/%1/%2").arg(theme->name(), theme->svgFileName()));
+    QString svgpath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QString("khangman/pics/%1/%2").arg(theme->name(), theme->svgFileName()));
     // we don't allow themes with no svg installed
 
     if (!QFile::exists(svgpath) || theme->svgFileName().isEmpty()) {
-        kDebug() << "SVG file doesn't exists";
+        qDebug() << "SVG file doesn't exist";
         return;
     }
 
@@ -281,21 +294,23 @@ void KHangManView::paintHangman(QPainter &p, const QRect& rect)
 
 void KHangManView::paintWord(QPainter &p, const QRect& rect)
 {
-    QRect myRect = m_theme->wordRect(size());
-    if (!myRect.intersects(rect)) {
-        return;
+    if (m_goodWord.size() > 0) {
+        QRect myRect = m_theme->wordRect(size());
+        if (!myRect.intersects(rect)) {
+            return;
+        }
+
+        p.setPen(m_theme->letterColor());
+
+        QFont tFont = LangUtils::fontForLanguage(Prefs::selectedLanguage());
+
+        tFont.setPointSize( height()/20 );
+
+        p.setFont(tFont);
+        // Set first letter as upper case for German
+        m_goodWord.replace(0, 1, LangUtils::capitalize(m_goodWord.at(0), Prefs::selectedLanguage()));
+        p.drawText(myRect, Qt::AlignCenter|Qt::AlignCenter, m_goodWord);
     }
-
-    p.setPen(m_theme->letterColor());
-
-    QFont tFont = LangUtils::fontForLanguage(Prefs::selectedLanguage());
-
-    tFont.setPointSize( height()/20 );
-
-    p.setFont(tFont);
-    // Set first letter as upper case for German
-    goodWord.replace(0, 1, LangUtils::capitalize(goodWord.at(0), Prefs::selectedLanguage()));
-    p.drawText(myRect, Qt::AlignCenter|Qt::AlignCenter, goodWord);
 }
 
 
@@ -425,7 +440,7 @@ void KHangManView::resizeEvent(QResizeEvent *)
     m_playAgainButton->setFont(QFont("Dustismo Roman", height()/32));
 
 
-    m_playAgainButton->setGeometry( width()/2 - m_playAgainButton->width()/2 , 
+    m_playAgainButton->setGeometry( width()/2 - m_playAgainButton->width()/2 ,
                                     height()/2 + m_playAgainButton->height()/2,
 				    m_playAgainButton->sizeHint().width(), height()/9 );
 }
@@ -436,12 +451,12 @@ void KHangManView::resizeEvent(QResizeEvent *)
 void KHangManView::slotTry()
 {
     QString guess = m_letterInput->text().toLower();
-    
+
     if (guess.isEmpty()) {
         m_letterInput->setFocus();
         return;
     }
-    kDebug() << "guess as entered: " << guess;
+    qDebug() << "guess as entered: " << guess;
 
     // Handle the guess.
     if (!m_guessedLetters.contains(guess)) {
@@ -451,7 +466,7 @@ void KHangManView::slotTry()
             replaceLetters(guess);
 
             // This is needed because of the white spaces.
-            QString  stripWord = goodWord;
+            QString  stripWord = m_goodWord;
             QString  sword     = m_word;
             if (m_posSecondSpace > 0)  {
                 stripWord.replace(2*m_posFirstSpace,   1, "");
@@ -469,11 +484,11 @@ void KHangManView::slotTry()
             // If the user made it...
             if (rightWord.trimmed().toLower() == sword.trimmed().toLower()) {
                 if (Prefs::sound()) {
-                    QString soundFile = KStandardDirs::locate("data", "khangman/sounds/EW_Dialogue_Appear.ogg");
+                    QString soundFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "khangman/sounds/EW_Dialogue_Appear.ogg");
                     play(soundFile);
                 }
                 m_winner=true;
-                ++winCount;
+                ++m_winCount;
                 setGameCount();
                 m_letterInput->setEnabled(false);
                 m_guessButton->setEnabled(false);
@@ -490,7 +505,7 @@ void KHangManView::slotTry()
             // Check if we have reached the limit of wrong guesses.
             if (m_numMissedLetters >= MAXWRONGGUESSES) {
                 m_loser=true;
-                ++lossCount;
+                ++m_lossCount;
                 setGameCount();
                 m_letterInput->setEnabled(false);
                 m_guessButton->setEnabled(false);
@@ -501,7 +516,7 @@ void KHangManView::slotTry()
         // The letter is already guessed.
 
         // Show a popup that says as much.
-        QPoint point; 
+        QPoint point;
         KPassivePopup *popup = new KPassivePopup( this );
         popup->setPopupStyle( KPassivePopup::Balloon );
         popup->setAutoDelete( true );
@@ -527,9 +542,9 @@ void KHangManView::slotTry()
             m_letterInput->setEnabled(false);
         }
 
-        if (goodWord.contains(guess) > 0) {
+        if (m_goodWord.contains(guess) > 0) {
             point = m_theme->goodWordPos(size(), popup->pos());
-            
+
             QTimer::singleShot( Prefs::missedTimer() * 1000,
                                 this, SLOT(enableUserInput()) );
 
@@ -553,23 +568,27 @@ void KHangManView::enableUserInput()
 }
 
 
-void KHangManView::newGame()
+void KHangManView::newGame(bool loss)
 {
     m_loser=false;
     m_winner=false;
     m_bgfill=0;
 
+    if (loss)
+        m_lossCount++;
+
     m_letterInput->setEnabled(true);
     m_guessButton->setEnabled(true);
     m_playAgainButton->setVisible(false);
 
     //reset Hint action
-    khangman->hintAct->setChecked(Prefs::hint());
-    khangman->hintAct->setEnabled(m_hintExists);
+    khangman->setHintEnabled(m_hintExists);
+
+    readFile();
 
     setGameCount();
     if (Prefs::sound()) {
-        QString soundFile = KStandardDirs::locate("data", "khangman/sounds/new_game.ogg");
+        QString soundFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "khangman/sounds/new_game.ogg");
         play(soundFile);
     }
 
@@ -602,7 +621,7 @@ void KHangManView::readFile()
 
 void KHangManView::reset()
 {
-    goodWord = "";
+    m_goodWord = "";
     m_word   = "";
 
     m_guessedLetters.clear();
@@ -616,8 +635,8 @@ void KHangManView::reset()
 
 void KHangManView::game()
 {
-    kDebug() << "language " << Prefs::selectedLanguage();
-    kDebug() << "level "    << Prefs::levelFile();
+    qDebug() << "language " << Prefs::selectedLanguage();
+    qDebug() << "level "    << Prefs::levelFile();
 
     m_word = m_randomList[m_randomInt%m_randomList.count()].first;
     m_word = m_word.toLower();
@@ -630,77 +649,77 @@ void KHangManView::game()
 
     if (m_hint.isEmpty()) {
         m_hintExists = false;   // Hint does not exist.
-        //TODO refresh hint action
     }
     else {
         m_hintExists = true;
-        //TODO refresh hint action
     }
-    khangman->hintAct->setEnabled(m_hintExists);
+    khangman->setHintEnabled(m_hintExists);
 
     // Display the number of letters to guess with _
     for (int i = 0; i < m_word.length(); i++) {
-        goodWord.append("_ ");
+        m_goodWord.append("_ ");
     }
 
     // Remove the last trailing space.
-    goodWord.remove(goodWord.length()-1);
+    m_goodWord.remove(m_goodWord.length()-1);
 
     // If needed, display white space or - if in word or semi dot.
 
     // 1. Find dashes.
     int posOfFirstDash = m_word.indexOf( "-" );
-    
+
     if (posOfFirstDash>0) {
-        goodWord.replace(2*posOfFirstDash, 1, "-");
+        m_goodWord.replace(2*posOfFirstDash, 1, "-");
         int posOfSecondDash = m_word.indexOf( "-", posOfFirstDash+1);
         if (posOfSecondDash>0) {
-            goodWord.replace(2*posOfSecondDash, 3, "-");
+            m_goodWord.replace(2*posOfSecondDash, 3, "-");
         }
         if (posOfSecondDash>1) {
-            goodWord.append("_");
+            m_goodWord.append("_");
         }
     }
 
     // 2. Find white space.
     m_posFirstSpace = m_word.indexOf( " " );
-    
+
     if (m_posFirstSpace > 0) {
-        goodWord.replace(2*m_posFirstSpace, 1, " ");
+        m_goodWord.replace(2*m_posFirstSpace, 1, " ");
         m_posSecondSpace = m_word.indexOf( " ", m_posFirstSpace+1);
         if (m_posSecondSpace > 0)
-            goodWord.replace(2*m_posSecondSpace, m_posFirstSpace+1, " ");
+            m_goodWord.replace(2*m_posSecondSpace, m_posFirstSpace+1, " ");
     }
 
     // 3. Find ·
     int posOfDot = m_word.indexOf( QString::fromUtf8("·") );
-    
+
     if (posOfDot>0) {
-        goodWord.replace(2*posOfDot, 1, QString::fromUtf8("·") );
+        m_goodWord.replace(2*posOfDot, 1, QString::fromUtf8("·") );
     }
 
     // 4. Find '
     int posOfApos = m_word.indexOf( "'" );
-    
+
     if (posOfApos>0) {
-        goodWord.replace(2*posOfApos, 1, "'");
+        m_goodWord.replace(2*posOfApos, 1, "'");
     }
 }
 
 
 void KHangManView::slotSetWordsSequence()
 {
-    kDebug() << "in read kvtml file ";
+    qDebug() << "in read kvtml file ";
 
     delete m_doc;
 
     m_doc = new KEduVocDocument(this);
     ///@todo open returns KEduVocDocument::ErrorCode
-    m_doc->open(Prefs::levelFile());
+    m_doc->open(QUrl::fromLocalFile(Prefs::levelFile()), KEduVocDocument::FileIgnoreLock);
 
     //how many words in the file
     int wordCount = m_doc->lesson()->entryCount(KEduVocLesson::Recursive);
 
+    qDebug() << "slotSetWordsSequence called, wordCount is " << wordCount;
+
     //get the words+hints
     KRandomSequence randomSequence;
     m_randomList.clear();
@@ -712,7 +731,7 @@ void KHangManView::slotSetWordsSequence()
             hint = m_doc->lesson()->entries(KEduVocLesson::Recursive).at(j)->translation(1)->text();
         }
         if (!m_doc->lesson()->entries(KEduVocLesson::Recursive).at(j)->translation(0)->text().isEmpty()) {
-            m_randomList.append(qMakePair(m_doc->lesson()->entries(KEduVocLesson::Recursive).at(j)->translation(0)->text(), hint));  
+            m_randomList.append(qMakePair(m_doc->lesson()->entries(KEduVocLesson::Recursive).at(j)->translation(0)->text(), hint));
         }
     }
     //shuffle the list
@@ -721,8 +740,8 @@ void KHangManView::slotSetWordsSequence()
 
 void KHangManView::setGameCount()
 {
-    emit signalChangeStatusbar(i18n("Wins: %1", winCount), IDS_WINS);
-    emit signalChangeStatusbar(i18n("Losses: %1", lossCount), IDS_LOSSES);
+    emit signalSetWins(m_winCount);
+    emit signalSetLosses(m_lossCount);
 }
 
 #include "khangmanview.moc"
